@@ -86,7 +86,8 @@ sub setup_template {
     $template_is_setup = 1;
 }
 
-package sql_block;
+package # sql_block
+    sql_block;
 use strict; use warnings;
 
 sub output_sql_mysql {
@@ -111,15 +112,17 @@ sub output_sql_mysql {
     return [ $output ];
 }
 
-package sequence_body;
+package # sequence_body
+    sequence_body;
 use strict; use warnings;
 
 sub output_sql_mysql {
-    warn "MySQL does not support user defined sequences.\n";
+    warn "Warning: MySQL does not support user defined sequences.\n";
     return;
 }
 
-package table_body;
+package # table_body
+    table_body;
 use strict; use warnings;
 
 sub output_sql_mysql {
@@ -143,7 +146,8 @@ sub output_sql_mysql {
     return [ $output ]
 }
 
-package table_element_block;
+package # table_element_block
+    table_element_block;
 use strict; use warnings;
 
 sub output_sql_mysql {
@@ -185,7 +189,8 @@ sub output_sql_mysql {
     }
 }
 
-package field_statement;
+package # field_statement
+    field_statement;
 use strict; use warnings;
 
 my %expansion_for = (
@@ -220,7 +225,8 @@ sub output_sql_mysql {
     return [ $output ];
 }
 
-package literal_block;
+package # literal_block
+    literal_block;
 use strict; use warnings;
 
 sub output_sql_mysql {
